@@ -27,7 +27,7 @@ our @EXPORT = qw(
 	
 );
 
-our $VERSION = '0.51';
+our $VERSION = '0.52';
 
 
 # Preloaded methods go here.
@@ -231,10 +231,13 @@ Script::Toolbox - Framework for the daily business scripts
   my $num = $m->run('MainMenue');        # terminate menue after first selection, return seleted option number
      $num = $m->run('MainMenue', 3);     # terminate menue after third selection, return last seleted option number
      $num = $m->run('MainMenue', 0);     # terminate never
-  my $opt = $m->currNumber('MainMenue'); # number of last seleted option
-  my $lbl = $m->currLabel ('MainMenue'); # label  of last seleted option
-  my $jmp = $m->currJump  ('MainMenue'); # callback address of last seleted option
-  my $val = $m->currValue ('MainMenue'); # data value of last seleted option
+  my $opt = $m->currNumber('MainMenue'); # return number of last seleted option
+  my $lbl = $m->currLabel ('MainMenue'); # return label  of last seleted option
+  my $jmp = $m->currJump  ('MainMenue'); # return callback address of last seleted option
+  my $val = $m->currValue ('MainMenue'); # return data value of last seleted option
+  my $lbl = $m->setCurrLabel ('MainMenue','newLabel'); # set label  of last seleted option
+  my $val = $m->setCurrValue ('MainMenue','newValue'); # set data value of last seleted option
+  my $jmp = $m->setCurrJump  ('MainMenue',\&newCB,$newArgv); # set callback address of last seleted option
 
   my $list= $m->getMatching('MainMenue','^[1]','number','label'); # return all labels where option number starts with one
   my $list= $m->getMatching('MainMenue','(min|low)','value','number'); # return all option numbers where value match min or low
@@ -593,25 +596,43 @@ last selected option.
 
 Get the number of the last selected option.
 
-  my $opt = $m->currNumber('MainMenue'); # number of last seleted option
+  my $opt = $m->currNumber('MainMenue');
 
 =item currLabel(<menueName>)
 
 Get the label of the last selected option.
 
-  my $lbl = $m->currLabel ('MainMenue'); # label  of last seleted option
+  my $lbl = $m->currLabel ('MainMenue');
 
 =item currJump(<menueName>)
 
 Get the address of the callback function of the last selected option.
 
-  my $jmp = $m->currJump  ('MainMenue'); # callback address of last seleted option
+  my $jmp = $m->currJump  ('MainMenue');
 
 =item currValue(<menueName>)
 
 Get the data field value of the last selected option.
 
-  my $val = $m->currValue ('MainMenue'); # data value of last seleted option
+  my $val = $m->currValue ('MainMenue'); 
+
+=item setCurrLabel(<menueName>,<newLabel>)
+
+Change the label string of the last selected option. Return the old label string.
+
+  my $old = $m->setCurrLabel ('MainMenue','newLabel'); 
+
+=item setCurrJump(<menueName>,\$newCB,$newArgv)
+
+Change the address of the callback function and argv of the last selected option.
+
+  my ($oldCB,$oldArgv) = $m->setCurrJump  ('MainMenue',<newCallBack>,<newArgv>); 
+
+=item setCurrValue(<menueName>,<newValue>)
+
+Change the data field value of the last selected option. Return the old value.
+
+  my $old = $m->currValue ('MainMenue','newValue');
 
 =item getMatching(<menueName>,<pattern>,<searchIn>,<return>)
 
