@@ -249,6 +249,7 @@ sub run($$){
 }
 
 #------------------------------------------------------------------------------
+# Return current nmber of selected option.
 #------------------------------------------------------------------------------
 sub currNumber($){
     my ($self,$name) = @_;
@@ -256,6 +257,7 @@ sub currNumber($){
 }
 
 #------------------------------------------------------------------------------
+# Return current label of selected option.
 #------------------------------------------------------------------------------
 sub currLabel($){
     my ($self,$name) = @_;
@@ -263,6 +265,7 @@ sub currLabel($){
 }
 
 #------------------------------------------------------------------------------
+# Return current value of selected option.
 #------------------------------------------------------------------------------
 sub currValue($){
     my ($self,$name) = @_;
@@ -270,15 +273,51 @@ sub currValue($){
 }
 
 #------------------------------------------------------------------------------
+# Return the callback address and argv address of selected option.
 #------------------------------------------------------------------------------
 sub currJump($){
     my ($self,$name) = @_;
 
     my $call = $self->{'def'}{$name}{'selected'}{'opt'}{'jump'};
     my $args = $self->{'def'}{$name}{'selected'}{'opt'}{'argv'};
+  
+    return $call,$args;
+}
 
-    $call->($args)  if( ref $call eq 'CODE');
-    return;
+#------------------------------------------------------------------------------
+# Set a new label for current selected option. Return old label.
+#------------------------------------------------------------------------------
+sub setCurrLabel($$){
+    my ($self,$name,$newLabel) = @_;
+
+    my $cn = $self->currNumber($name) -1;
+    my $ol = $self->{'def'}{$name}{'opts'}[$cn]{'label'};
+             $self->{'def'}{$name}{'opts'}[$cn]{'label'} = $newLabel;
+    return $ol;
+}
+
+#------------------------------------------------------------------------------
+# Set a new value for current selected option. Return old value.
+#------------------------------------------------------------------------------
+sub setCurrValue($$){
+    my ($self,$name,$newValue) = @_;
+
+    my $cn = $self->currNumber($name) -1;
+    my $ov = $self->{'def'}{$name}{'opts'}[$cn]{'value'};
+             $self->{'def'}{$name}{'opts'}[$cn]{'value'} = $newValue;
+    return $ov;
+}
+
+#------------------------------------------------------------------------------
+# Set new callback address und argv for the current selected option.
+#------------------------------------------------------------------------------
+sub setCurrJump($$$){
+    my ($self,$name,$callBack,$argv) = @_;
+
+    my $cn = $self->currNumber($name) -1;
+    $self->{'def'}{$name}{'opts'}[$cn]{'jump'} = $callBack;
+    $self->{'def'}{$name}{'opts'}[$cn]{'argv'} = $argv;
+    return $callBack,$argv;
 }
 
 #------------------------------------------------------------------------------
