@@ -1097,7 +1097,9 @@ sub _jump($$)
     my $call = $menue->[$o]->{'jump'};
     my $args = defined $menue->[$o]->{'argv'} ? $menue->[$o]->{'argv'} : undef;
 
-    $call->(@{$args});
+    #FIXME: deprecated, callback should handle data struct by its own 
+    #FIXME: $call->(@{$args});
+    $call->($args);
     return;
 }
 
