@@ -39,7 +39,7 @@ sub main
     my $o = Script::Toolbox->new( $O );
 
     my $m = Script::Toolbox::Util::Menues->new({'SubMenue1'=>[{'label'=>'test','value'=>10}]});
-       $m->addMenue({'MainMenue'=>[{'label'=>'test1', 'value'=>10,'readOnly'=>1},
+       $m->addMenue({'MainMenue'=>[{'label'=>'test1', 'value'=>1 ,'readOnly'=>1},
                                    {'label'=>'test2', 'value'=>20,},
                                    {'label'=>'test3', 'value'=>30,},
                                    {'label'=>'Untermenue 1','jump'=>'SubMenue1'}
@@ -50,12 +50,23 @@ sub main
     printf "\n%s\n", '-' x 20;
     my $v = $m->getMatching('MainMenue','test','label','value');
     printf "Values of Labels /test/  : %s\n", join ' ', @{$v};
-    my $v = $m->getMatching('MainMenue','(1|3)','number','value');
+       $v = $m->getMatching('MainMenue','(1|3)','number','value');
     printf "Values of Numbers /(1|3)/: %s\n", join ' ', @{$v};
-    my $v = $m->getMatching('MainMenue','\d+','value','label');
+       $v = $m->getMatching('MainMenue','\d+','value','label');
     printf "Labels of Values /\d+/   : %s\n", join ' ', @{$v};
     printf "\n%s\n", '-' x 20;
 
+    while( $m->run('MainMenue')) {
+            if( $m->currNumber('MainMenue') == 1 ) {
+                my $v = $m->currValue('MainMenue');
+                my $nv= $v == 0 ? 1 : 0;
+                my $lb= $nv == 0 ? 'test1-off' : 'test1-on';
+                $m->setCurrValue('MainMenue',$nv);
+                $m->setCurrLabel('MainMenue',$lb);
+
+            }
+    }
+
 #    my $t = Table([ 'Util-Table',
 #                    [ '--H1--',  '--H2--', '--H3--'],
 #                    [ '11:11:11',  33.456, 'cc  '  ],
